@@ -37,7 +37,8 @@ static struct uci_package *wifidog_uci_load()
 {
     struct uci_package *p = NULL;
 
-    cursor = uci_alloc_context();
+    if (!cursor)
+        cursor = uci_alloc_context();
 
     if (uci_load(cursor, "wifidog-ng", &p) && p)
         uci_perror(cursor, "");
@@ -446,12 +447,19 @@ static int serve_roam(struct ubus_context *ctx, struct ubus_object *obj,
              struct blob_attr *msg)
 {
     struct blob_attr *tb[__ROAM_MAX];
+    struct terminal *term;
 
     blobmsg_parse(roam_policy, __ROAM_MAX, tb, blob_data(msg), blob_len(msg));
 
     if (!tb[ROAM_MAC] || !tb[ROAM_IP])
         return UBUS_STATUS_INVALID_ARGUMENT;
 
+    term = term_new(blobmsg_data(tb[ROAM_MAC]), blobmsg_data(tb[ROAM_IP]));
+    if (!term) {
+        ULOG_ERR("term_new failed: No mem\n");
+        return 0;
+    }
+
     authserver_request(NULL, AUTH_REQUEST_TYPE_ROAM, blobmsg_data(tb[ROAM_IP]), blobmsg_data(tb[ROAM_MAC]), NULL);
     return 0;
 }
@@ -496,4 +504,7 @@ void wifidog_ubus_free()
 {
     if (ctx)
         ubus_free(ctx);
+
+    if (cursor)
+        uci_free_context(cursor);
 }
