@@ -31,8 +31,10 @@
 #include <arpa/inet.h>
 #include <libubox/ulog.h>
 
+#include "ipset.h"
 #include "utils.h"
 #include "resolv.h"
+#include "config.h"
 
 int get_iface_ip(const char *ifname, char *dst, int len)
 {
@@ -183,30 +185,25 @@ int disable_kmod()
     return kmod_ctl(NULL, false);
 }
 
-static int destip_ctl(const char *ip, bool allow)
+static void destip_ctl(const char *ip, bool allow)
 {
-    FILE *fp = fopen("/proc/wifidog-ng/ip", "w");
-    if (!fp) {
-        ULOG_ERR("Kernel module is not loaded\n");
-        return -1;
-    }
-
-    fprintf(fp, "%c%s\n", allow ? '+' : '-', ip);
-    fclose(fp);
+    printf("destip_ctl: %s\n", ip);
+    if (allow)
+        ipset_add("wifidog-ng-ip", ip, 0);
+    else
+        ipset_del("wifidog-ng-ip", ip);
 
     ULOG_INFO("%s destip: %s\n", ip, allow ? "allow" : "deny");
-
-    return 0;
 }
 
-int allow_destip(const char *ip)
+void allow_destip(const char *ip)
 {
-    return destip_ctl(ip, true);
+    destip_ctl(ip, true);
 }
 
-int deny_destip(const char *ip)
+void deny_destip(const char *ip)
 {
-    return destip_ctl(ip, false);
+    destip_ctl(ip, false);
 }
 
 static void my_resolv_cb(struct hostent *he, void *data)
@@ -224,59 +221,58 @@ static void my_resolv_cb(struct hostent *he, void *data)
     }
 }
 
-static int domain_ctl(const char *domain, bool allow)
+static void domain_ctl(const char *domain, bool allow)
 {
     int ip[4];
 
     if (sscanf(domain, "%d.%d.%d.%d", ip + 0, ip + 1, ip + 2, ip + 3) == 4) {
         destip_ctl(domain, allow);
-        return 0;
+        return;
     }
 
     resolv_start(domain, my_resolv_cb, (void *)allow);
-    return 0;
 }
 
-int allow_domain(const char *domain)
+void allow_domain(const char *domain)
 {
-    return domain_ctl(domain, true);
+    domain_ctl(domain, true);
 }
 
-int deny_domain(const char *domain)
+void deny_domain(const char *domain)
 {
-    return domain_ctl(domain, false);
+    domain_ctl(domain, false);
 }
 
-static int termianl_ctl(const char *mac, const char *token, char action)
+bool is_valid_ip(const char *ip)
 {
-    FILE *fp;
+    struct sockaddr_in sa;
 
-    fp = fopen("/proc/wifidog-ng/term", "w");
-    if (!fp) {
-        ULOG_ERR("fopen:%s\n", strerror(errno));
-        return -1;
+    if (!ip)
+        return false;
+
+    return (inet_pton(AF_INET, ip, &(sa.sin_addr)) != 0);
+}
+
+bool is_valid_mac(const char *mac)
+{
+    int i = 0;
+    int s = 0;
+
+    if (!mac || strlen(mac) != 17)
+        return 0;
+
+    while (*mac) {
+        if (isxdigit(*mac)) {
+            i++;
+        } else if (*mac == ':' || *mac == '-') {
+            if (i == 0 || i / 2 - 1 != s)
+                break;
+            ++s;
+        } else {
+            s = -1;
+        }
+        ++mac;
     }
 
-
-    fprintf(fp, "%c%s %s\n", action, mac, token ? token : "");
-    fclose(fp);
-
-    ULOG_INFO("termianl ctl: %c %s\n", action, mac);
-
-    return 0;
-}
-
-int allow_termianl(const char *mac, const char *token, bool temporary)
-{
-    return termianl_ctl(mac, token, temporary ? '?' : '+');
-}
-
-int deny_termianl(const char *mac)
-{
-    return termianl_ctl(mac, "", '-');
-}
-
-int whitelist_termianl(const char *mac)
-{
-    return termianl_ctl(mac, "", '!');
+    return (i == 12 && (s == 5 || s == 0));
 }
\ No newline at end of file
