@@ -27,19 +27,18 @@ int get_iface_ip(const char *ifname, char *dst, int len);
 int get_iface_mac(const char *ifname, char *dst, int len);
 int arp_get(const char *ifname, const char *ip, char *dst, int len);
 
-int allow_destip(const char *ip);
-int deny_destip(const char *ip);
+void allow_destip(const char *ip);
+void deny_destip(const char *ip);
 
-int allow_domain(const char *domain);
-int deny_domain(const char *domain);
+void allow_domain(const char *domain);
+void deny_domain(const char *domain);
 
 int urlencode(char *buf, int blen, const char *src, int slen);
 
 int enable_kmod(const char *interface);
 int disable_kmod();
 
-int allow_termianl(const char *mac, const char *token, bool temporary);
-int deny_termianl(const char *mac);
-int whitelist_termianl(const char *mac);
+bool is_valid_ip(const char *ip);
+bool is_valid_mac(const char *mac);
 
 #endif
